TaskLibrary "Siebel Operational Tasks" {
        Context = ("","TEC",1);
        Distribute = ("","ALI",1);
        HelpMessage = ("SIEBEL_GuiHelp","<The Operational Tasks task library defines tasks that perform administrative functions of the application.>  ",18);
        Requires = ("",">2.1",1);
        Version = ("","1.1",1);

        ArgLayout ArchiveOptions {
                RadioButton  {
                        { ("SIEBEL_Gui","List Log Archives",152) "list" }
                        { ("SIEBEL_Gui","Create Archive",153) "archive" }
                };;
        };
        ArgLayout CompGrpOptions {
                RadioButton  {
                        { ("SIEBEL_Gui","Online",133) "online" }
                        { ("SIEBEL_Gui","Offline",134) "offline" }
                };;
        };
        ArgLayout ListOptions {
                RadioButton  {
                        { ("SIEBEL_Gui","Components",130) "components" }
                        { ("SIEBEL_Gui","Component Groups",131) "compgrps" }
                        { ("SIEBEL_Gui","Tasks",132) "tasks" }
                };;
        };
        ArgLayout PasswordLayout {
                CryptoText;
        };
        ArgLayout TaskOptions {
                RadioButton  {
                        { ("SIEBEL_Gui","Pause",122) "pause" }
                        { ("SIEBEL_Gui","Resume",123) "resume" }
                        { ("SIEBEL_Gui","Start",124) "start" }
                        { ("SIEBEL_Gui","Stop",125) "stop" }
                };;
        };
        ArgLayout TextLayout {
                Text;
        };
        ArgLayout YesNo {
                RadioButton  {
                        { ("SIEBEL_Gui","Yes",90) "y" }
                        { ("SIEBEL_Gui","No",91) "n" }
                };;
        };

        Task "Archive_Siebel_Logs" {
                Description = ("SIEBEL_Gui","Archive Siebel Logs",106);
                HelpMessage = ("SIEBEL_GuiHelp","Archive_Siebel_Logs
This task enables administrators to do the following:
      *  View a listing of the archived Siebel Server log directories.
      *  Tar, compress, and remove old Siebel log archive directories.

      Using this task, a Siebel administrator who wants to keep old
      Siebel log archive directories can compress the logs and move them
      to a different location.

      For more information, see the IBM Tivoli Monitoring for
      Applications, version 5.1.0 - Siebel eBusiness Applications
      User's Guide.

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      List Log Archives
               List the logarchive directories along with their size in
               kilobytes, the timestamp on the directory, and the free
               space on the filesystem containing the log archives in
               kilobytes.

      Create Archive
               Create an archive file. When you select this option, you
               must also specify the following:

               Archive directory/filename
                        The directory and filename where the archive log
                        file is created. Examples: C:/temp/archive.tar.Z
                        or /opt/oldlogs/siebarch.tar.Z. If only a file is
                        specified, such as \"name.tar.Z\", the file is
                        created in the logarchive directory. You do not
                        have to specify \".tar.Z\" on the archive
                        filename. The current time and date is automatically
                        appended to the name you specify.

               Archive Age 'x'
                        Specify an integer that is equal to the minimum age
                        in days of directories you would like added
                        to the archive file and deleted from the Siebel
                        Server logarchive directory. An archive is not
                        created if there are no directories as old or
                        older than the age you specify.

   CLI syntax
      Archive_Siebel_Logs
      -a { list | archive }
      -a <archive_file_name>
      -a <minimum_age_of_dirs_to_archive>

      where:

      list     List the logarchive directories along with their size in
               kB, the timestamp on the directory, and the free space on
               the filesystem containing the log archives in kBs.

      archive  Create an archive file. If you select this option, you
               must also specify the following:

               archive_file_name
                        Specify the directory and filename where the
                        archive log file is created. Examples:
                        C:/temp/archive or
                        /opt/oldlogs/siebellogs.tar.Z If you only specify a
                        file, such as \"name.tar.Z\", the file is created
                        in the logarchive directory. You do not have to
                        specify \".tar.Z\" on the archive filename.
                        The current time and date is appended to the name
                        of the file that you specify.

               minimum_age_of_dirs_to_archive
                        Specify an integer that is equal to an age
                        in days. All archive directories that are as
                        old or older will be added to the archive file
                        specified in the previous parameter.

   CLI example

      The following example creates the file /tmp/archive_200204160823.tar.Z
      that contains any log archive directories from the Siebel
      Server named \"server\" in enterprise \"enterprise\" that are 4 days
      old or older. The archived directories are removed from the Siebel
      Server's \"logarchive\" directory.

      wruntask
      -t Archive_Siebel_Logs
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:server@enterprise@hostname
      -a archive
      -a /tmp/archive
      -a 4

   See also

      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",11);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Option:",126) {
                        DefaultValue = ("","list",1);
                        Layout = ("","ArchiveOptions",1);
                };
                Argument ("SIEBEL_Gui","Archive directory and filename:",154) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Argument ("SIEBEL_Gui","Archive Age (in days)",155) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Implementation ("default") Binary "tasks/siebel_archive_logs.sh";
        };
        Task "Check_Server_Status" {
                Description = ("SIEBEL_Gui","Check Server Status",108);
                HelpMessage = ("SIEBEL_GuiHelp","Check_Server_Status

",12);
                Roles = ("","siebel_admin:siebel_senior:siebel_user",1);
                Uid = ("","$root_user",1);
                Implementation ("default") Binary "tasks/siebel_check_status.sh";
        };
        Task "Control_Component_Groups" {
                Description = ("SIEBEL_Gui","Control Component Groups",109);
                HelpMessage = ("SIEBEL_GuiHelp","Control_Component_Groups
      Allows a component group to be taken online or offline.

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      Online   Brings online a Siebel component group on a Siebel
               Application server.

      Offline  Brings offline a Siebel component group on a Siebel
               Application server.

      Component Group
               Alias name of a Siebel Component Group.

   CLI syntax
      Control_Component_Groups
      -a {online | offline }
      -a <componentgroupname>

   CLI example
      wruntask
      -t Control_Component_Groups
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:Server@enterprise@pinball
      -a online
      -a <componentgroupname>

   See also
      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",2);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Option:",126) {
                        DefaultValue = ("","Offline",1);
                        Layout = ("","CompGrpOptions",1);
                };
                Argument ("SIEBEL_Gui","Component Group Alias",120) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Implementation ("default") Binary "tasks/siebel_control_compgrps.sh";
        };
        Task "Control_Siebel_Tasks" {
                Description = ("SIEBEL_Gui","Control Siebel Tasks",110);
                HelpMessage = ("SIEBEL_GuiHelp","Control_Siebel_Tasks
Allows Siebel tasks to be started, stopped, paused, or resumed.

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      Pause    Pause a running task.

      Resume   Resume a paused task.

      Start    Start a new task as an instance of the specified
               component.

      Stop     Stop a running task.

      Task Number
               Task number for the running task. This option is required
               for the Pause, Resume, and Stop options and is valid only
               for these options.

      Start Component Name
               Name of the component to start as a task. This function
               is required for the Start option and is valid only for
               this option.

      Start Task Parameters
               Any parameters for the task. This function is valid only
               for the Start option.

   CLI syntax
      Control_Siebel_Tasks
      -a {pause | resume| start| stop }
      -a <number>| \"\"
      -a <task name>| \"\"
      -a <parameters>| \"\"

   CLI example
      wruntask
      -t Control_Siebel_Tasks
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:Server@enterprise@pinball
      -a stop
      -a 1234

   See also
      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",1);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Option:",126) {
                        DefaultValue = ("","list",1);
                        Layout = ("","TaskOptions",1);
                };
                Argument ("SIEBEL_Gui","Task Number",127) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Argument ("SIEBEL_Gui","Start Component Name",128) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Argument ("SIEBEL_Gui","Start Task Parameters",129) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Implementation ("default") Binary "tasks/siebel_control_tasks.sh";
        };
        Task "Run_List_Command" {
                Description = ("SIEBEL_Gui","Run srvrmgr list command",111);
                HelpMessage = ("SIEBEL_GuiHelp","Run_List_Command
Allows current data for components, component groups, or Siebel
tasks to be listed for a Siebel server.

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      Components
               Lists the current components defined for the Siebel
               server.

      Component Groups
               Lists the current component groups defined for the Siebel
               server.

      Tasks    Displays current data about tasks on a Siebel server.

   CLI syntax
      Run_List_Command
      -a {components | compgrps | tasks }

   CLI example
      wruntask
      -t Run_List_Command
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:Server@enterprise@pinball
      -a components

   See also
      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",14);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Option:",126) {
                        DefaultValue = ("","Components",1);
                        Layout = ("","ListOptions",1);
                };
                Implementation ("default") Binary "tasks/siebel_run_list.sh";
        };
        Task "Run_Srvrmgr_Command" {
                Description = ("SIEBEL_Gui","Run Srvrmgr Command",118);
                HelpMessage = ("SIEBEL_GuiHelp","Run_Srvrmgr_Command
Runs any valid srvrmgr command on a Siebel Application server
such as \"list servers\" and  \"enable compgrp <component_group>\".

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      Srvrmgr Command
               Any valid command string that can be executed at the
               srvrmgr> prompt

   CLI syntax
      Run_Srvrmgr_Command
      -a <SrvmgrCommand>

      where:
      SrvmgrCommand
               Any valid command string that can be executed at the
               srvrmgr> prompt

   CLI example
      wruntask
      -t Run_Srvrmgr_Command
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:Server@enterprise@pinball
      -a \"list servers\"

   See also

      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",16);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Srvrmgr Command",121) {
                        DefaultValue = ("","",1);
                        Layout = ("","TextLayout",1);
                };
                Implementation ("default") Binary "tasks/siebel_run_srvrmgr.sh";
        };
        Task "Start_Siebel_Server" {
                Description = ("SIEBEL_Gui","Start Siebel Server",112);
                HelpMessage = ("SIEBEL_GuiHelp","Start_Siebel_Server

",13);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Implementation ("default") Binary "tasks/siebel_start_server.sh";
        };
        Task "Stop_Siebel_Server" {
                Description = ("SIEBEL_Gui","Stop Siebel Server",116);
                HelpMessage = ("SIEBEL_GuiHelp","Stop_Siebel_Server
Stops the specified Siebel Server. Running this task also updates
the server object icon.

   Authorization role
      siebel_senior or siebel_admin

   Target managed resource
      SIEBELServer

   GUI data entry fields
      where:

      Yes      Confirms running of the task stopping the Siebel Servers
               targeted.

      No       Cancels running of the task stopping the Siebel Servers
               targeted.

   CLI syntax
      Stop_Siebel_Server
      -a {y | n }

   CLI example
      wruntask
      -t Stop_Siebel_Server
      -l \"Siebel Operational Tasks\"
      -h @SIEBELServer:Server@enterprise@pinball
      -a \"y\"

   See also

      The following commands in the Tivoli Management Framework
      Reference Manual: wruntask, wcrtjob and wgettask.

",15);
                Roles = ("","siebel_admin:siebel_senior",1);
                Uid = ("","$root_user",1);
                Argument ("SIEBEL_Gui","Please confirm",144) {
                        DefaultValue = ("","y",1);
                        Layout = ("","YesNo",1);
                };
                Implementation ("default") Binary "tasks/siebel_stop_server.sh";
        };

}

